@@ -1,6 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gtksourceundomanager.c
  * This file is part of GtkSourceView
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
@@ -122,9 +121,13 @@ gtk_source_undo_manager_default_init (GtkSourceUndoManagerIface *iface)
 			      G_TYPE_FROM_INTERFACE (iface),
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 			      G_STRUCT_OFFSET (GtkSourceUndoManagerIface, can_undo_changed),
-			      NULL, NULL, NULL,
+			      NULL, NULL,
+		              g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	g_signal_set_va_marshaller (signals[CAN_UNDO_CHANGED],
+	                            G_TYPE_FROM_INTERFACE (iface),
+	                            g_cclosure_marshal_VOID__VOIDv);
 
 	/**
 	 * GtkSourceUndoManager::can-redo-changed:
@@ -140,9 +143,13 @@ gtk_source_undo_manager_default_init (GtkSourceUndoManagerIface *iface)
 			      G_TYPE_FROM_INTERFACE (iface),
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 			      G_STRUCT_OFFSET (GtkSourceUndoManagerIface, can_redo_changed),
-			      NULL, NULL, NULL,
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	g_signal_set_va_marshaller (signals[CAN_REDO_CHANGED],
+	                            G_TYPE_FROM_INTERFACE (iface),
+	                            g_cclosure_marshal_VOID__VOIDv);
 }
 
 /**
